clear; clc;

% Predator Ecology book, Chapter 2
% Code to make Figure 2.1
% Functional response parameter space from FoRAGE (Uiterwaal et al 2018)

figure(1);clf(1);
    subplot(131);    
    hold on; box on;

    [num txt] = xlsread('Sarma_et_al_2013','Sheet1');
    spider_prey = num(:,1);
    spider_fpc = num(:,3);

    % set up fit
    ft = fittype( 'a*x', 'independent', 'x', 'dependent', 'y' );
    opts = fitoptions( ft );
    opts.Lower = [0];
    opts.StartPoint = [1];
    opts.Upper = [Inf];

    % run simple OLS fit
    [fitresult, gof] = fit( spider_prey, spider_fpc, ft, opts );
    coeffs = coeffvalues(fitresult); % pull fitted parameters
    a = coeffs(1); % space clearance rate is parameter 1
    x = 0:0.001:0.04; % specify a range of x's for plotting
    fit_type_I = a.*x; % calculate curve    
    
    plot(spider_prey,spider_fpc,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
    plot(x,fit_type_I,'-k');
    title('Type I');
    xlabel('Prey cm^{-2}','FontSize',10);
    ylabel('Prey consumed','FontSize',10);
    %axis([0 250 0 50]);
    
%%
subplot(1,3,2);
    hold on; box on;
    
    [num txt] = xlsread('Sarma_et_al_2013','Sheet1');
    cyclops_prey = num(:,1);
    cyclops_fpc = num(:,3);

    ft = fittype( 'a*x/(1+a*h*x)', 'independent', 'x', 'dependent', 'y' );
    opts = fitoptions( ft );
    opts.Display = 'Off';
    opts.Lower = [0 0];
    opts.StartPoint = [1 0.5];
    opts.Upper = [Inf Inf];

    [fitresult, gof] = fit( cyclops_prey, cyclops_fpc, ft, opts );
    gof.rsquare
    coeffs = coeffvalues(fitresult);
    a = coeffs(1);
    h = coeffs(2);
    x = 0:250;
    fit_type_II = a.*x./(1+a.*h.*x);

    plot(cyclops_prey, cyclops_fpc ,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
    plot(x,fit_type_II,'-k');
    xlabel('Prey 40 mL^{-1}','FontSize',10);
    ylabel('Prey consumed h^{ -1}','FontSize',10);
    title('Type II');
    axis([0 250 0 50]);

%%
subplot(133);
hold on; box on;
    [num txt] = xlsread('Sarmento_et_al_2007','Sheet1');
    ladybug_prey = num(1:19,5);
    ladybug_fpc = num(1:19,9);
    
    % Set up fittype and options.
    ft = fittype( 'a*x^q/(1+a*h*x^q)', 'independent', 'x', 'dependent', 'y' );
    opts = fitoptions( ft );
    opts.Display = 'Off';
    opts.Lower = [0 0 0];
    opts.StartPoint = [1 0.5 1];
    opts.Upper = [Inf Inf Inf];

    [fitresult, gof] = fit( ladybug_prey, ladybug_fpc, ft, opts );
    coeffs = coeffvalues(fitresult);
    a = coeffs(1);
    h = coeffs(2);
    q = coeffs(3);
    x = 0:15;
    fit_type_III = a.*x.^q./(1+a.*h.*x.^q);

    plot(ladybug_prey, ladybug_fpc ,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
    plot(x,fit_type_III,'-k');
    xlabel('Prey cm^{-2}','FontSize',10);
    ylabel('Prey consumed h^{ -1}','FontSize',10);
    title('Type III');
    %axis([0 15 0 0.6]);    
    shg;
%% For figure 2.2, location of parameters
% a_plot = 2;
% h_plot = 0.05;
% q_plot = 1.5;
% x = 0:0.01:50;
% y = a_plot.*x./(1+a_plot.*h_plot.*x);
% y2 = a_plot.*x.^q_plot./(1+a_plot.*h_plot.*x.^q_plot);
% 
% figure(2);clf(2);
% subplot(221);
%     hold on; box on;
%     plot(x,y,'-k','LineWidth',2);
%     plot([0 150],[1/h_plot 1/h_plot],':k');
%     plot([0 8],[0 8].*a_plot,'--k');
%     xlabel('Prey density','FontSize',12);
%     ylabel('Foraging rate','FontSize',12);
%     axis([0 40 0 25]);
%     title('Type II');
% 
% subplot(222);
%     hold on; box on;
%     plot(x,y2,'-k','LineWidth',2);
%     plot([0 150],[1/h_plot 1/h_plot],':k');
%     axis([0 40 0 25]);
%     title('Type III');
%     
% subplot(223);
%     hold on; box on;
%     plot(x,y2,'-k','LineWidth',2);
%     plot([0 8],[0 8],'--k');
%     axis([0 0.5 0 0.5]);
%     
% subplot(224);
%     hold on; box on;
%     plot(x,a_plot.*x.^q_plot,'-k');
%     plot([0 10],[a_plot a_plot],'--k');
%     axis([0 5 0 20]);
%     
% shg;
% 
% gtext('Slope is \ita');
% gtext('Asymptote is 1/\ith');
% gtext('A','FontSize',12);
% gtext('B','FontSize',12);

%% For figure 2.3, interference inspiders

% [num txt] = xlsread('Functional responses for figures','Figure 2');
% crickets = num(:,11)./0.75;
% spiders = num(:,13)./0.75;
% kill_rate = num(:,15);
% 
% [xData, yData, zData] = prepareSurfaceData( crickets, spiders, kill_rate );
% 
% % Set up fittype and options.
% ft = fittype( 'a*x*y^m/(1 + a*h*x*y^m)', 'independent', {'x', 'y'}, 'dependent', 'z' );
% opts = fitoptions( ft );
% opts.Display = 'Off';
% opts.Lower = [-Inf -Inf -Inf];
% opts.StartPoint = [0.957506835434298 0.964888535199277 0.157613081677548];
% opts.Upper = [Inf Inf Inf];
% 
% % Fit model to data.
% [fitresult, gof] = fit( [xData, yData], zData, ft, opts );
% gof.rsquare
% coeffs = coeffvalues(fitresult);
% a = coeffs(1)
% h = coeffs(2)
% m = coeffs(3)
% 
% % Plot fit with data
% figure(3);clf(3);
% box on;
% plot3(crickets,spiders,kill_rate,'o','Color','w','MarkerFaceColor','k'); hold on;
% [X,Y] = meshgrid([min(crickets):10:max(crickets)], [min(spiders):max(spiders)]);
% predicted = (a.*X.*Y.^m) ./ (1 + a.*h.*X.*Y.^m);
% surf(X,Y,predicted,'FaceColor',[0.8 0.8 0.8]);
% 
% % Label axes
% xlabel('Crickets m^{ -2}','FontSize',12);
% ylabel('Spiders m^{ -2}','FontSize',12);
% zlabel('Crickets eaten day^{ -1}','FontSize',12);
% grid on
