clear; clc;

% Predator Ecology book, Chapter 2
% Code to make Figure 2.1
% Functional response types

figure(1);clf(1); % open up and clear a figure

%% I'll use different sections for the four panels - first is type I

subplot(2,2,1); % subplots of 2 rows, 2 columns, panel 1    
hold on; box on;

% read in data
[num txt] = xlsread('Monteleone_and_Duguay_1988','Sheet1');
anchovy_prey = num(:,7); % pull prey levels
anchovy_fpc = num(:,9); % pull foraging rate

% set up fit
ft = fittype( 'a*x', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );

% run simple OLS fit
[fitresult, gof] = fit( anchovy_prey, anchovy_fpc, ft, opts );
coeffs = coeffvalues(fitresult); % pull fitted parameters
a = coeffs(1); % space clearance rate is parameter 1
x = 0:10:max(anchovy_prey); % specify a range of x's for plotting
fit_type_I = a.*x; % calculate curve    

% now plot
plot(anchovy_prey,anchovy_fpc,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
plot(x,fit_type_I,'-k');
title('Type I');
xlabel('Anchovies m^{-3}','FontSize',10);
ylabel('Anchovies consumed d^{-1}','FontSize',10);
    
shg;
%% section 2, type II

subplot(2,2,2);
hold on; box on;

% read in data
[num txt] = xlsread('Sarma_et_al_2013','Sheet1');
cyclops_prey = num(:,1); % pull prey levels
cyclops_fpc = num(:,3); % pull foraging rate

% set up fit
ft = fittype( 'a*x/(1+a*h*x)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Lower = [0 0];
opts.StartPoint = [1 0.5];
opts.Upper = [Inf Inf];

% run simple OLS fit
[fitresult, gof] = fit( cyclops_prey, cyclops_fpc, ft, opts );
coeffs = coeffvalues(fitresult);
a = coeffs(1);
h = coeffs(2);
x = 0:250;
fit_type_II = a.*x./(1+a.*h.*x);

plot(cyclops_prey, cyclops_fpc ,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
plot(x,fit_type_II,'-k');
xlabel('Rotifers 40 mL^{-1}','FontSize',10);
ylabel('Rotifers consumed h^{ -1}','FontSize',10);
title('Type II');
axis([0 250 0 50]);

shg;
%% section 3, type III

subplot(223);
hold on; box on;

% read in data
[num txt] = xlsread('Sarmento_et_al_2007','Sheet1');
ladybug_prey = num(:,5);
ladybug_fpc = num(:,9);

% Set up fittype and options.
ft = fittype( 'a*x^q/(1+a*h*x^q)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.Lower = [0 0 0];
opts.StartPoint = [1 0.005 1];
opts.Upper = [Inf Inf Inf];

% run simple OLS fit
[fitresult, gof] = fit( ladybug_prey, ladybug_fpc, ft, opts )
coeffs = coeffvalues(fitresult);
a = coeffs(1);
h = coeffs(2);
q = coeffs(3);
x = 0:0.2:max(ladybug_prey);
fit_type_III = a.*x.^q./(1+a.*h.*x.^q);

% now plot
plot(ladybug_prey, ladybug_fpc ,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
plot(x,fit_type_III,'-k');
xlabel('Aphids cm^{-2}','FontSize',10);
ylabel('Aphids consumed d^{ -1}','FontSize',10);
title('Type III');

shg;
%% section 3, type IV

subplot(2,2,4);
hold on; box on;

% read in data
[num txt] = xlsread('Liznarova_and_Pekar_2013','Sheet1');
ant_prey = num(:,5);
ant_fpc = num(:,9);

% Set up fittype and options.
ft = fittype( 'a*x/(1+a*h*x^q)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.Lower = [0 0 0];
opts.StartPoint = [1 0.005 1];
opts.Upper = [Inf Inf Inf];

% run simple OLS fit
[fitresult, gof] = fit( ant_prey, ant_fpc, ft, opts )
coeffs = coeffvalues(fitresult);
a = coeffs(1);
h = coeffs(2);
q = coeffs(3);
x = 0:0.2:max(ant_prey);
fit_type_IV = a.*x./(1+a.*h.*x.^q);

% now plot
plot(ant_prey, ant_fpc ,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
plot(x,fit_type_IV,'-k');
xlabel('Ants m^{-2}','FontSize',10);
ylabel('Ants consumed d^{ -1}','FontSize',10);
title('Type IV');

shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
gtext('C','FontSize',12);
gtext('D','FontSize',12);
