clear; clc;

% Predator Ecology book, Chapter 2
% Code to make Figure 2.3
% Interference in spiders, data from Schmidt et al 2014 Oecologia

[num txt] = xlsread('Schmidt_et_al_2014','Sheet1');
crickets = num(:,11)./0.75; % original data were per 0.75 m^2
spiders = num(:,13)./0.75;
kill_rate = num(:,15);

% Set up fittype and options.
ft = fittype( 'a*x*y^m/(1 + a*h*x*y^m)', 'independent', {'x', 'y'}, 'dependent', 'z' );
opts = fitoptions( ft );
opts.Lower = [0 0 -Inf];
opts.StartPoint = [0.95 0.96 -0.5];
opts.Upper = [Inf Inf Inf];

% Fit model to data
[fitresult, gof] = fit( [crickets, spiders], kill_rate, ft, opts );
coeffs = coeffvalues(fitresult);
a = coeffs(1);
h = coeffs(2);
m = coeffs(3);

% Plot fit with data
figure(1);clf(1);
box on;
plot3(crickets,spiders,kill_rate,'o','Color','w','MarkerFaceColor',[0 0.45 0.74]); hold on;
[X,Y] = meshgrid([min(crickets):10:max(crickets)], [min(spiders):max(spiders)]);
predicted = (a.*X.*Y.^m) ./ (1 + a.*h.*X.*Y.^m);
surf(X,Y,predicted,'FaceColor',[0.8 0.8 0.8]);

x2 = 0:20:max(crickets);
single_pred = a.*x2.*min(spiders).^m./(1 + a.*h.*x2.*min(spiders).^m);
plot3(x2,min(spiders).*ones(size(x2)),single_pred,'--','Color',[1 0.55 0],'LineWidth',2);

% Label axes
xlabel('Crickets m^{-2}','FontSize',12);
ylabel('Spiders m^{-2}','FontSize',12);
zlabel('Crickets eaten day^{-1}','FontSize',12);
grid on
