clear; clc;

% Predator Ecology book, Chapter 3
% Code to make Figure 3.3, effect of habitat complexity
% Based on data from Wasserman et al 2016

% read in data
[num,words] = xlsread('Wasserman_et_al_2016.xlsx','Sheet1'); % read in data
ds = num(:,1);
num_offered_no_hab = num(find(ds==672),20);
num_eaten_no_hab = num(find(ds==672),21);
num_offered_low_hab = num(find(ds==674),20);
num_eaten_low_hab = num(find(ds==674),21);
num_offered_high_hab = num(find(ds==676),20);
num_eaten_high_hab = num(find(ds==676),21);
% Set up fittype and options
% Here we will use LambertW version of the Roger's Random Predator Equation
% Duration of the experiment was 18 hours
ft = fittype( 'x - lambertw(a*h*x*exp(-a*(18 - h*x)))/(a*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.StartPoint = [0.01 0.01];
opts.Lower = [0 0];

x = 0:1:max(num_offered_no_hab); % a sequence of x's to calculate over

[no_hab_result, no_hab_gof] = fit(num_offered_no_hab,num_eaten_no_hab,ft,opts); % do the fit for males
    no_hab_coeffs = coeffvalues(no_hab_result); % output the parameters
    a_no_hab = no_hab_coeffs(1);
    h_no_hab = no_hab_coeffs(2);
    no_hab_curve = x-lambertw(a_no_hab.*h_no_hab.*x.*exp(-a_no_hab.*(18-h_no_hab.*x)))./(a_no_hab.*h_no_hab);

[low_hab_result, low_hab_gof] = fit(num_offered_low_hab,num_eaten_low_hab,ft,opts); % do the fit for males
    low_hab_coeffs = coeffvalues(low_hab_result); % output the parameters
    a_low_hab = low_hab_coeffs(1);
    h_low_hab = low_hab_coeffs(2);
    low_hab_curve = x-lambertw(a_low_hab.*h_low_hab.*x.*exp(-a_low_hab.*(18-h_low_hab.*x)))./(a_low_hab.*h_low_hab);

[high_hab_result, high_hab_gof] = fit(num_offered_high_hab,num_eaten_high_hab,ft,opts); % do the fit for males
    high_hab_coeffs = coeffvalues(high_hab_result); % output the parameters
    a_high_hab = high_hab_coeffs(1);
    h_high_hab = high_hab_coeffs(2);
    high_hab_curve = x-lambertw(a_high_hab.*h_high_hab.*x.*exp(-a_high_hab.*(18-h_high_hab.*x)))./(a_high_hab.*h_high_hab);

figure(1);clf(1);
    box on; hold on;
    plot(num_offered_no_hab,num_eaten_no_hab,'s','Color',[1 0.55 0],'MarkerFaceColor',[1 0.55 0]);
    plot(num_offered_no_hab,num_eaten_low_hab,'o','Color',[0 0.45 0.74],'MarkerFaceColor',[0 0.45 0.74]);
    plot(num_offered_no_hab,num_eaten_high_hab,'ok','MarkerFaceColor','k');
    h1 = plot(x,no_hab_curve,'-','Color',[1 0.55 0],'LineWidth',2);
    h2 = plot(x,low_hab_curve,':','LineWidth',2,'Color',[0 0.45 0.74]);
    h3 = plot(x,high_hab_curve,'-k','LineWidth',2);
    legend([h1 h2 h3],'No habitat','Low habitat','High habitat','Location','Best');
    xlabel('Number of prey offered','FontSize',12);
    ylabel('Number of prey consumed','FontSize',12);
    
shg;