clear; clc;

% Predator Ecology book, Chapter 3
% Code to make Figure 3.4
% Functional response parameter space from FoRAGE (Uiterwaal et al 2018)

[num, words] = xlsread('FoRAGE db 12_19_18.xlsx','Sources'); % read in treatment data

h = num(:,41); 
a = num(:,38); 
D = num(:,4);
pred_mass = num(:,29);
group1 = words(2:size(words,1),9);
group2 = words(2:size(words,1),10);
group3 = words(2:size(words,1),11);

%% plot
figure(1); clf(1);

% first to all 3D foragers
lm = fitlm(log(pred_mass),log(a)); % linear model (regression)
x = 10.^[-8:1:8]; % new sequence of x's
[ps_a, cis_a] = predict(lm,log(x'));

subplot(2,1,1); % all 3D foragers here
    box on;
    loglog(pred_mass,a,'ow','MarkerFaceColor',[0.5 0.5 0.5]); hold on;
    plot(x,exp(ps_a),'-k','LineWidth',2);
    jbfill(x,exp(cis_a(:,1))',exp(cis_a(:,2))',[0.8 0.8 0.8],'w',1,0.4); hold on;
    ylabel('Space clearance rate (mL pred^{-1} day^{-1})','FontSize',12); 
    ylim([1e-15 1e10]);
    xlim([1e-8 1e8]);
    title('All 3D foragers');
    grid on;

subplot(2,1,2); % protists, copepods, and fishes here
	box on;

% protist linear model
    pred_mass_p = pred_mass(ismember(group1,'Protozoan'),:);
    a_p = a(ismember(group1,'Protozoan'),:);
    lm_p = fitlm(log(pred_mass_p),log(a_p)); % linear model (regression)
    x = 10.^[-8:1:-1]; % new sequence of x's
    [ps_a, cis_a] = predict(lm_p,log(x'));
    
% protist plots
    h1 = loglog(pred_mass_p,a_p,'<w','MarkerFaceColor',[0 0.45 0.74]); hold on;
    plot(x,exp(ps_a),'-k','LineWidth',2);
    jbfill(x,exp(cis_a(:,1))',exp(cis_a(:,2))',[0.8 0.8 0.8],'w',1,0.4); hold on;
        
% copepod model
    pred_mass_c = pred_mass(ismember(group3,'Copepod'),:);
    a_c = a(ismember(group3,'Copepod'),:);
    lm_c = fitlm(log(pred_mass_c),log(a_c)); % linear model (regression)
    x = 10.^[-5:1:1]; % new sequence of x's
    [ps_c, cis_c] = predict(lm_c,log(x'));
    
% copepod plot
    h2 = loglog(pred_mass_c,a_c,'ow','MarkerFaceColor',[1 0.55 0]); hold on;
    plot(x,exp(ps_c),'-k','LineWidth',2);
    jbfill(x,exp(cis_c(:,1))',exp(cis_c(:,2))',[0.8 0.8 0.8],'w',1,0.4); hold on;

% fish model
    pred_mass_f = pred_mass(ismember(group2,'Fish'),:);
    a_f = a(ismember(group2,'Fish'),:);
    lm_f = fitlm(log(pred_mass_f),log(a_f)); % linear model (regression)
    x = 10.^[-2:1:7]; % new sequence of x's
    [ps_f, cis_f] = predict(lm_f,log(x'));
    
% fish plot
    h3 = loglog(pred_mass_f,a_f,'sw','MarkerFaceColor','k'); hold on;
    plot(x,exp(ps_f),'-k','LineWidth',2);
    jbfill(x,exp(cis_f(:,1))',exp(cis_f(:,2))',[0.8 0.8 0.8],'w',1,0.4); hold on;
    legend([h1 h2 h3],'Protists','Copepods','Fish');
    xlabel('Predator body mass (mg)','FontSize',12);
    title('Protists, copepods, and fishes');
    grid on;
    
    ylim([1e-15 1e10]);
    xlim([1e-8 1e8]);
    
shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);