clear; clc;

% Predator Ecology book, Chapter 3
% Code to make Figure 3.5
% Functional response variation based on Gergs and Ratte 2009
% Data digitized and as presented in FoRAGE (Uiterwaal et al 2018)

[num text] = xlsread('Gergs_Ratte_2009.xlsx','Raw data'); % read in treatment data

data_set = num(:,1);
prey = num(:,7);
foraging_rate = num(:,9);

figure(1);clf(1);
subplot(2,1,1);
    hold on; box on;
    z1 = plot(prey(data_set==433),foraging_rate(data_set==433),'-ok','LineWidth',2);
    z2 = plot(prey(data_set==434),foraging_rate(data_set==434),'--o','Color',[1 0.55 0],'LineWidth',2);
    z3 = plot(prey(data_set==435),foraging_rate(data_set==435),'-.o','Color',[0.5 0.5 0.5],'LineWidth',2);
    z4 = plot(prey(data_set==436),foraging_rate(data_set==436),':o','Color',[0 0.45 0.74],'LineWidth',2);
    legend([z1 z2 z3 z4],'Small','Medium','Large','XLarge',...
        'Location','Best');
    xlabel('Prey density (prey mL^{-1})','FontSize',12);
    ylabel('Foraging rate (prey pred^{-1} day^{-1})','FontSize',12);

%%
[num text] = xlsread('Gergs_Ratte_2009.xlsx','Parameter sets'); % read in treatment data
data_set = num(:,1);
a = num(:,4);
pred_type = text(2:length(a),1);
prey_type = text(2:length(a),2);

a_run = a(1:length(a));
a_plot = reshape(a_run,[4,5])';
prey_plot = [1:4].*ones(5,4);

subplot(2,1,2);
    hold on; box on;
    h1 = plot(prey_plot(1,:),a_plot(1,:),'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    h2 = plot(prey_plot(2,:),a_plot(2,:),'--','Color',[1 0.55 0],'LineWidth',2);
    h3 = plot(prey_plot(3,:),a_plot(3,:),':','Color',[0 0.45 0.74],'LineWidth',2);
    h4 = plot(prey_plot(4,:),a_plot(4,:),'-','Color',[0 0.45 0.74],'LineWidth',2);
    h5 = plot(prey_plot(5,:),a_plot(5,:),'-k','LineWidth',2);

    legend([h1 h2 h3 h4 h5],'1st instar','2nd instar','3rd instar','4th instar','5th instar',...
        'Location','Best');
    xlim([0.5 4.5]);
    xticks([1 2 3 4])
    xticklabels({'Small','Medium','Large','XLarge'})
    xlabel('Prey size class','FontSize',12);
    ylabel('Space clearance rate (mL pred^{-1} day^{-1})','FontSize',12);   
shg;

gtext('A','FontSize',12); 
gtext('B','FontSize',12); 
