clear; clc;

% Predator Ecology book, Chapter 3
% Code to make Figure 3.6
% Functional responses varying with temperature and sex

[num,words] = xlsread('Ding_Xu_2007.xlsx','Raw data'); % read in treatment data
prey = num(:,7);
foraging_rate = num(:,8);

[num,words] = xlsread('Ding_Xu_2007.xlsx','Parameter sets'); % read in treatment data
a = num(:,4);
h = num(:,5);
temperature = num(:,3);

x = 1000.*(0:5:100); % a sequence of x's to calculate over
fpc = a.*x./(1+a.*h.*x); % predict foraging with Holling disc equation

figure(1);clf(1);
subplot(2,2,1);
    hold on; box on;
    h1 = plot(x,fpc(1,:),'-k','LineWidth',2);
    h2 = plot(x,fpc(3,:),'--','Color',[0 0.45 0.74],'LineWidth',2);
    h3 = plot(x,fpc(5,:),'-.','Color',[0.5 0.5 0.5],'LineWidth',2);
    h4 = plot(x,fpc(7,:),':','Color',[1 0.55 0],'LineWidth',2);
    ylabel('Foraging rate (prey day^{-1})','FontSize',12); 
    xlim([0 1e5]);
    
subplot(2,2,2);
    hold on; box on;
    h1 = plot(x,fpc(2,:),'-k','LineWidth',2);
    h2 = plot(x,fpc(4,:),'--','Color',[0 0.45 0.74],'LineWidth',2);
    h3 = plot(x,fpc(6,:),'-.','Color',[0.5 0.5 0.5],'LineWidth',2);
    h4 = plot(x,fpc(8,:),':','Color',[1 0.55 0],'LineWidth',2);
    legend([h1 h2 h3 h4],'20','25','30','35','Location','Best');
    xlabel('Prey density (ind m^{-2})','FontSize',12); 
    ylim([0 60]);

subplot(2,2,3);
    hold on; box on;
    a_run = a(1:length(a));
    a_plot = reshape(a_run,[2,4]);
    temps = unique(temperature);
    h1 = plot(temps,a_plot(1,:),'-ok','Color',[0 0.45 0.74],'LineWidth',2);
    h2 = plot(temps,a_plot(2,:),'--sk','Color',[1 0.55 0],'LineWidth',2);
    legend([h1 h2],'Females','Males','Location','Best');
	ylabel({['Space clearance rate'],['(mL pred^{-1} day^{-1})']},'FontSize',12); 

subplot(2,2,4);
    hold on; box on;     
    h_run = h(1:length(h));
    h_plot = reshape(h_run,[2,4]);    
    plot(temps,h_plot(1,:),'-ok','Color',[0 0.45 0.74],'LineWidth',2);
    plot(temps,h_plot(2,:),'--sk','Color',[1 0.55 0],'LineWidth',2);
    xlabel('Temperature (^{o}C)','FontSize',12); 
    ylabel('Handling time (days)','FontSize',12); 
    
shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
gtext('C','FontSize',12);
gtext('D','FontSize',12);