clear; clc; 

% Predator Ecology book, Chapter 4
% Code to make Figure 4.2
% daphnia-algae predator-prey cycle based on DeLong et al 2018

% read in data
[num words] = xlsread('Daphnia_algae_densities_M6_alt.xls','Sheet1');
days = num(:,2);
algae = num(:,3);
daphnia = num(:,4);

% model parameters generated by ODE fitting
r = 0.242;
a = 0.175;
d = 0.093;
K = 3.68E5;
e = 1.05E-05;

% solve model for fitted parameters
y0 = [9.755e4 0.0023]; % initial prey and predator densities
tspan = [0 56]; % start end times
ode = @(t,y) MR_model(t,y,r,K,a,e,d); % compile function and call
    [t1,y1] = ode23(ode, tspan, y0); % return time and population density vectors

figure(1);clf(1);
    box on; hold on; 
    h1 = plot(days,algae.*1e-5,'ok','MarkerFaceColor','k');
    plot(t1,y1(:,1).*1e-5,'-k','LineWidth',2);
    h2 = plot(days,daphnia,'o','Color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5]);
    plot(t1,y1(:,2),'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    xlabel('Days','FontSize',12);
    ylabel({['Population density'],['Daphnia mL^{-1}'],['Algae *10^{5} mL^{-1}']},'FontSize',12);
    legend([h1 h2],'Algae','Daphnia','Location','Best');
    
shg;