clear; clc; 

% Predator Ecology book, Chapter 4
% Code to make Figures 4.3 and 4.4
% predator prey dynamics based on Slough and Mowat 1986

years = 0:1:7;
hare = [0.8 1 2.8 5.7 7.5 4.7 1.3 1.1];
lynx = [2.7E-4 5.6E-4 1.06E-3 2.43E-3 4.45E-3 4.49E-3 4.3E-4 2.00E-4];

% model parameters generated by ODE fitting
r = 1.387;
a = 148.648;
d = 23.654;
h = 0.000355;
K = 1371;
m = -0.677;
e = 0.00912;

% solve model for fitted parameters
y0 = [hare(1) lynx(1)]; % initial prey and predator densities
tspan = [0 8]; % start end times
ode = @(t,y) MR_model_int_K(t,y,r,K,a,h,e,d,m); % compile function and call
    [t1,y1] = ode23(ode, tspan, y0); % return time and population density vectors

figure(1);clf(1);
    box on;hold on; 
    plot(years,hare,'ok','MarkerFaceColor','k');
    h1 = plot(t1,y1(:,1),'-k','LineWidth',2);
    plot(years,lynx.*1e3,'o','Color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5]);
    h2 = plot(t1,y1(:,2).*1e3,'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    legend([h1 h2],'Hares','Lynx','Location','Best');
    xlabel('Years','FontSize',12);
    ylabel({['Population density'],['Hares ha^{-1}'],['Lynx *10^{-3} ha^{-1}']},'FontSize',12);

%% now solve model again with higher and lower parameters
ode = @(t,y) MR_model_int_K(t,y,r,K,0.99*a,h,e,d,m); % compile function and call
    [t2,y2] = ode45(ode, tspan, y0); % return time and population density vectors
ode = @(t,y) MR_model_int_K(t,y,r,K,1.01*a,h,e,d,m); % compile function and call
    [t3,y3] = ode45(ode, tspan, y0); % return time and population density vectors

figure(2);clf(2);
subplot(2,2,1);
    box on;hold on; 
    plot(t1,y1(:,1),'-k','LineWidth',2);
    plot(t2,y2(:,1),'--k','Color',[0 0.45 0.74],'LineWidth',2);
    plot(t3,y3(:,1),':','Color',[1 0.55 0],'LineWidth',2);
    ylabel({['Population density'],['Hares ha^{-1}']},'FontSize',12);
    xlim([0 7]);
    
subplot(2,2,3);
box on; hold on;
    plot(t1,y1(:,2).*1e3,'-','Color',[0.5 0.5 0.5],'LineWidth',2);
    plot(t2,y2(:,2).*1e3,'--','Color',[0 0.45 0.74],'LineWidth',2);
    plot(t3,y3(:,2).*1e3,':','Color',[1 0.55 0],'LineWidth',2);
    ylabel({['Population density'],['Lynx *10^{-3} ha^{-1}']},'FontSize',12);
    xlim([0 7]);
    
subplot(2,2,2);
ode = @(t,y) MR_model_int_K(t,y,r,K,a,0.99*h,e,d,m); % compile function and call
    [t4,y4] = ode45(ode, tspan, y0); % return time and population density vectors

ode = @(t,y) MR_model_int_K(t,y,r,K,a,1.01*h,e,d,m); % compile function and call
    [t5,y5] = ode45(ode, tspan, y0); % return time and population density vectors

    box on; hold on;
    plot(t1,y1(:,1),'-k','LineWidth',2);
    z1 = plot(t4,y4(:,1),'--','Color',[0 0.45 0.74],'LineWidth',2);
    z2 = plot(t5,y5(:,1),':','Color',[1 0.55 0],'LineWidth',2);
    legend([z1 z2],'1% lower','1% higher');
    xlim([0 7]);
    
subplot(2,2,4);
box on; hold on;
    plot(t1,y1(:,2).*1e3,'-','Color',[0.5 0.5 0.5],'LineWidth',2);
    plot(t4,y4(:,2).*1e3,'--','Color',[0 0.45 0.74],'LineWidth',2);
    plot(t5,y5(:,2).*1e3,':','Color',[1 0.55 0],'LineWidth',2);
    xlim([0 7]);
    xlabel('Years','FontSize',12);
    
shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
gtext('C','FontSize',12);
gtext('D','FontSize',12);
