clear; clc;

% Predator Ecology book, Chapter 4
% Code to make Figure 4.5
% vector diagrams for models shown in Figures 4.2 and 4.3

%% Left panel, daphnia-algae vectors

% data from DeLong et al 2018
% model parameters generated by ODE fitting
r = 0.306;
a = 0.208;
d = 0.093;
K = 3.36E5;
e = 1.12E-05;

y0 = [9.755e4 0.0023]; % initial prey and predator densities
tspan = [0 56]; % start end times
ode = @(t,y) MR_model(t,y,r,K,a,e,d); % compile function and call
    [t1,y1] = ode23(ode, tspan, y0); % return time and population density vectors

figure(1); clf(1);
subplot(211);
    hold on; box on;
    [x y]=meshgrid(0:1e4:K,0:0.25:3.5);
    dx = r.*x.*(1-x./K)-a.*x.*y;
    dy = e.*a.*x.*y-d.*y;
    L=sqrt((dx./1e5).^2+dy.^2);
    quiver(x./1e5,y,(dx./L)./1e5,dy./L,0.4,'Color','k'); axis tight; hold on;
    plot(4.5e4./1e5,1.1,'ok','MarkerFaceColor','k');
    plot(y1(:,1)./1e5,y1(:,2),'-k');
    plot(y1(1,1)./1e5,y1(1,2),'>k','MarkerFaceColor','k');
    xlabel('Algae *10^{5} mL^{-1}','FontSize',12);
    ylabel('Daphnia mL^{-1}','FontSize',12);

%% lynx-hare vectors

% after Slough and Mowatt 1986
% model parameters generated by ODE fitting
r = 1.387;
a = 148.648;
d = 23.654;
h = 0.000355;
K = 1371;
m = -0.677;
e = 0.00912;

% solve model for fitted parameters
y0 = [0.8 2.7E-4]; % initial prey and predator densities
tspan = [0 7]; % start end times
ode = @(t,y) MR_model_int_K(t,y,r,K,a,h,e,d,m); % compile function and call
    [t1,y1] = ode23(ode, tspan, y0); % return time and population density vectors

subplot(212);
    hold on; box on;
    [x y]=meshgrid(0.2:0.5:9.7,0:0.5e-3:6e-3);
    dx = r.*x.*(1-x./K)-a.*x.*y.^(m+1)./(1+a.*h.*x.*y.^m);
    dy = e.*a.*x.*y.^(m+1)./(1+a.*h.*x.*y.^m)-d.*y;
    L=sqrt(dx.^2+(dy./1e-3).^2);
    quiver(x,y./1e-3,(dx./L),(dy./L)./1e-3,0.4,'Color','k'); axis tight; hold on;
    plot(y1(:,1),y1(:,2)./1e-3,'-k');
    plot(y1(1,1),y1(1,2)./1e-3,'>k','MarkerFaceColor','k');
    plot(2.47,0.00132./1e-3,'ok','MarkerFaceColor','k');   
    xlabel('Hare ha^{-1}','FontSize',12);
    ylabel('Lynx *10^{-3} ha^{-1}','FontSize',12);

shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);