clear; clc;

% Predator Ecology book, Chapter 5
% Code to make Figure 5.1
% MSFR illustration based on Colton 1987

%% left panel, single species functional responses

% FR data
density = 6*[4 12 20 28 36 44]; % prey per L, * 6 L
diaptomus_eaten = [5.392 22.507 22.281 28.386 27.060 32.339]; % prey eaten per 24 hours
simocephalus_eaten = [14.838 30.344 42.990 38.196 42.667 49.863]; % prey eaten per 24 hours

% fitted FR parameters
d_a = 0.024;
d_h = 0.6;
s_a = 0.055;
s_h = 0.44;
t = 24;
x = 0:25:300;

% calculate curve using LambertW RRP
d_curve = x-lambertw(d_a.*d_h.*x.*exp(-d_a.*(t-d_h.*x)))./(d_a.*d_h);
s_curve = x-lambertw(s_a.*s_h.*x.*exp(-s_a.*(t-s_h.*x)))./(s_a.*s_h);

figure(1);clf(1);
subplot(2,1,1);
    box on; hold on;
    plot(density,diaptomus_eaten,'o','Color',[1 0.55 0],'MarkerFaceColor',[1 0.55 0]);
    h1 = plot(x,d_curve,'-','Color',[1 0.55 0],'LineWidth',2);
    plot(density,simocephalus_eaten,'o','Color',[0 0.45 0.74],'MarkerFaceColor',[0 0.45 0.74]);
    h2 = plot(x,s_curve,'-','Color',[0 0.45 0.74],'LineWidth',2);    
    legend([h1 h2],'{\itDiaptomus}','{\itSinocephalus}','Location','Best');
    xlabel('Number of prey offered','FontSize',12);
    ylabel('Number of prey consumed','FontSize',12);

%% righ panel, multi species functional responses

[X,Y] = meshgrid(x,x);
Z1 = nan(size(X));
Z2 = nan(size(X));
% cycle through combinations of x and y
for i = 1:length(x)*length(x)
    number_d = X(i);
    number_s = Y(i);
    
    % make initial guesses from single-species FR
    d_curve = number_d-lambertw(d_a.*d_h.*number_d.*exp(-d_a.*(t-d_h.*number_d)))./(d_a.*d_h);
    s_curve = number_s-lambertw(s_a.*s_h.*number_s.*exp(-s_a.*(t-s_h.*number_s)))./(s_a.*s_h);

    [z, fval] = fsolve(@(z)MSFR_two_species(z,number_d,number_s,d_a,d_h,s_a,s_h,t), [d_curve s_curve]);
    Z1(i) = z(1);
    Z2(i) = z(2);
    
end

% now plot out the surfaces of the MSFR
subplot(2,1,2); 
    box on; hold on;
    grid on;
    s1 = surf(X,Y,Z1,'FaceAlpha',0.5,'FaceColor',[1 0.55 0]);
    s2 = surf(X,Y,Z2,'FaceAlpha',0.5,'FaceColor',[0 0.45 0.74]);
    s3 = surf(X,Y,Z1+Z2,'FaceAlpha',0.5,'FaceColor','w');
    xlabel('{\itDiaptomus} offered');
    ylabel('{\itSinocephalus} offered');
    zlabel('Number eaten');
    legend([s1 s2 s3],'{\itDiaptomus}','{\itSinocephalus}','Combined');
shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
