clear; clc; 

% Predator Ecology book, Chapter 6
% Code to make Figure 6.1
% predator prey dynamics based on Slough and Mowat 1986

years = 0:1:7;
hare = [0.8 1 2.8 5.7 7.5 4.7 1.3 1.1];
lynx = [2.7E-4 5.6E-4 1.06E-3 2.43E-3 4.45E-3 4.49E-3 4.3E-4 2.00E-4];

% model parameters generated by ODE fitting
r = 1.387;
a = 148.648;
d = 23.654;
h = 0.000355;
K = 1371;
m = -0.677;
e = 0.00912;

% solve model for fitted parameters
y0 = [hare(1) lynx(1)]; % initial prey and predator densities
tspan = [0 15]; % start end times
ode = @(t,y) MR_model_int_K(t,y,r,K,a,h,e,d,m); % compile function and call
    [t1,y1] = ode23(ode, [0:0.5:15], y0); % return time and population density vectors

figure(1);clf(1);
subplot(411);
    box on;hold on;
    h1 = plot(t1,y1(:,1),'-k','LineWidth',2);
    h2 = plot(t1,y1(:,2).*1e3,'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    legend([h1 h2],'Hares','Lynx','Location','Best');
    ylabel({['Population density'],['Hares ha^{-1}'],['Lynx *10^{-3} ha^{-1}']},'FontSize',12);

% calculate and plot pc population growth rates
pcgr_lynx = e.*a.*y1(:,1).*y1(:,2).^m./(1+a.*h.*y1(:,1).*y1(:,2).^m) - d;
pcgr_hare = r.*(1-y1(:,1)./K) - a.*y1(:,2).^(m+1)./(1+a.*h.*y1(:,1).*y1(:,2).^m);

subplot(412);
    box on;hold on;
    h2 = plot(t1,pcgr_lynx,'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    h1 = plot(t1,pcgr_hare,'-k','LineWidth',2);
    plot(tspan,[0 0],'--k');
    ylabel({['Per capita'],['growth rate']},'FontSize',12);
    ylim([-2.5 1.5]);

% calculate and plot fitness gradients for space clearance rate
fg_a_hare = -y1(:,2).^(m+1)./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);
fg_a_lynx = e.*y1(:,1).*y1(:,2).^m./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);

subplot(413);
    box on;hold on;
    h1 = plot(t1,fg_a_hare,'-k','LineWidth',2);
    h2 = plot(t1,fg_a_lynx,'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    plot(tspan,[0 0],'--k');
    ylim([-0.005 0.025]);
    ylabel('{\deltaW} / {\deltaa}','FontSize',12);
    xlabel('Years','FontSize',12);

% calculate and plot fitness gradients for handling time
fg_h_hare = a.^2.*y1(:,1).*y1(:,2).^(2.*m+1)./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);
fg_h_lynx = -e.*a.^2.*y1(:,1).^2.*y1(:,2).^(2.*m)./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);

subplot(414);
    box on; hold on;
    h1 = plot(t1,fg_h_hare,'-k','LineWidth',2);
    h2 = plot(t1,fg_h_lynx,'--','Color',[0.5 0.5 0.5],'LineWidth',2);
    plot(tspan,[0 0],'--k');
    ylim([-8 2].*1e4);
    ylabel('{\deltaW} / {\deltah}','FontSize',12);
    xlabel('Years','FontSize',12);

shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
gtext('C','FontSize',12);
gtext('D','FontSize',12);