clear; clc; 

% Predator Ecology book, Chapter 6
% Code to make Figure 6.2
% predator prey dynamics based on Slough and Mowat 1986

years = 0:1:7;
hare = [0.8 1 2.8 5.7 7.5 4.7 1.3 1.1];
lynx = [2.7E-4 5.6E-4 1.06E-3 2.43E-3 4.45E-3 4.49E-3 4.3E-4 2.00E-4];

% model parameters generated by ODE fitting
r = 1.387;
a = 148.648;
d = 23.654;
h = 0.000355;
K = 1371;
m = -0.677;
e = 0.00912;

% solve model for fitted parameters
y0 = [hare(1) lynx(1)]; % initial prey and predator densities
tspan = [0 15]; % start end times
ode = @(t,y) MR_model_int_K(t,y,r,K,a,h,e,d,m); % compile function and call
    [t1,y1] = ode23(ode, tspan, y0); % return time and population density vectors

% calculate and plot fitness gradients for space clearance rate
fg_a_hare = -y1(:,2).^(m+1)./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);
fg_a_lynx = e.*y1(:,1).*y1(:,2).^m./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);

% calculate and plot fitness gradients for handling time
fg_h_hare = a.^2.*y1(:,1).*y1(:,2).^(2.*m+1)./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);
fg_h_lynx = -e.*a.^2.*y1(:,1).^2.*y1(:,2).^(2.*m)./((1 + a.*h.*y1(:,1).*y1(:,2).^m).^2);
    
figure(1);clf(1);
    subplot(211);
    box on;hold on;    
    plot3(fg_a_lynx,fg_a_hare,y1(:,2)./y1(:,1),'-k');
    plot3(fg_a_lynx(1),fg_a_hare(1),y1(1,2)./y1(1,1),'ok');
    plot3(fg_a_lynx(10),fg_a_hare(10),y1(10,2)./y1(10,1),'<k');
    grid on;
    title('Space clearance rate');
    
    xlabel({['Lynx fitness'],['gradient']},'FontSize',12);
    ylabel({['Hare fitness'],['gradient']},'FontSize',12);
    zlabel('Lynx:hare ratio','FontSize',12);
    
    subplot(212);
    box on;hold on;    
    plot3(fg_h_lynx,fg_h_hare,y1(:,2)./y1(:,1),'-k');
    plot3(fg_h_lynx(1),fg_h_hare(1),y1(1,2)./y1(1,1),'ok');
    plot3(fg_h_lynx(10),fg_h_hare(10),y1(10,2)./y1(10,1),'<k');
    grid on;
    title('Handling time');
    
    xlabel({['Lynx fitness'],['gradient']},'FontSize',12);
    ylabel({['Hare fitness'],['gradient']},'FontSize',12);
    zlabel('Lynx:hare ratio','FontSize',12);
    
    shg;
    
gtext('A','FontSize',12);
gtext('B','FontSize',12);