clear; clc;

% Predator Ecology book, Chapter 6
% Code to make Figure 6.3
% Data from Livdahl 1979

% read in data
[num,words] = xlsread('Livdahl.xlsx','Sheet1'); % read in data
num_offered_NC = num(1:40,1);
num_eaten_NC = num(1:40,2);

num_offered_IL = num(41:82,1);
num_eaten_IL = num(41:82,2);

% Set up fittype and options
% Here we will use LambertW version of the Roger's Random Predator Equation
% Duration of the experiment was 24 hours
ft = fittype( 'x - lambertw(a*h*x*exp(-a*(24 - h*x)))/(a*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.Lower = [0 0];
opts.StartPoint = [1 0.04];

x = 0:48;
t = 24; % duration of experiment

[NC_result, NC_gof] = fit(num_offered_NC,num_eaten_NC,ft,opts); % do the fit for males
    NC_coeffs = coeffvalues(NC_result); % output the parameters
    a_NC = NC_coeffs(1);
    h_NC = NC_coeffs(2);
    NC_curve_II = x-lambertw(a_NC.*h_NC.*x.*exp(-a_NC.*(24-h_NC.*x)))./(a_NC.*h_NC);

[IL_result, IL_gof] = fit(num_offered_IL,num_eaten_IL,ft,opts); % do the fit for females
    IL_coeffs = coeffvalues(IL_result); % output the parameters
    a_IL = IL_coeffs(1);
    h_IL = IL_coeffs(2);
    IL_curve_II = x-lambertw(a_IL.*h_IL.*x.*exp(-a_IL.*(24-h_IL.*x)))./(a_IL.*h_IL);

%% now plot

% lots of points exactly the same, so we'll nudge them for visibility
jitter_NC = 1 + 0.02*randn(length(num_offered_NC),1);
jitter_IL = 1 + 0.02*randn(length(num_offered_IL),1);

figure(1);clf(1);
box on; hold on;
    h1 = plot(num_offered_NC.*jitter_NC,num_eaten_NC,'ok');
    plot(x,NC_curve_II,'--k','LineWidth',2);
    h2 = plot(num_offered_IL.*jitter_IL,num_eaten_IL,'ok','MarkerFaceColor',[0.5 0.5 0.5]);
    plot(x,IL_curve_II,'-k','LineWidth',2);
    legend([h1 h2],'North Carolina','Illinois','Location','Best');
    xlim([0 50]);
    xlabel('Prey offered','FontSize',12);
    ylabel('Prey consumed','FontSize',12);

shg;
