clear; clc;

% Predator Ecology book, Chapter 8
% Code to make Figure 8.1
% Based on data from Fernando 1977 via Cock 1974
% Data digitzed from Figures 2.A

% DN = deutonymph
% L = larvae

% functional response experiment data
DN_offered = [1 2 4 8 16 32];% DN = deutonymphs
DN_consumed = [0.8 1.48 2.82 3.47 4.07 3.99];
L_offered = [1 2 4 8 16 32 48]; % L = larvae
L_consumed = [1.00 2.04 3.77 6.00 8.60 9.94 10.31];

% functional response parameters fitted to Lambert Random Predator equation
L_a = 0.1338;
L_h = 2.153;
DN_a = 0.1224;
DN_h = 5.533;
x = 0:50;
t = 24; % duration of experiment

% use Lambert Random Predator equation to predict curves
L_curve = x-lambertw(L_a.*L_h.*x.*exp(-L_a.*(t-L_h.*x)))./(L_a.*L_h);
DN_curve = x-lambertw(DN_a.*DN_h.*x.*exp(-DN_a.*(t-DN_h.*x)))./(DN_a.*DN_h);

figure(1);clf(1);
    box on; hold on;
    plot(DN_offered,DN_consumed,'ok','MarkerFaceColor','k');
    h1 = plot(x,DN_curve,'-k','LineWidth',2);
    plot(L_offered,L_consumed,'o','Color',[0.5 0.5 0.5],'MarkerFaceColor',[0.5 0.5 0.5]);
    h2 = plot(x,L_curve,'-','Color',[0.5 0.5 0.5],'LineWidth',2);
    legend([h1 h2],'Deutonymphs','Larvae','Location','Best');
    xlabel('Number of prey offered','FontSize',12);
    ylabel('Number of prey consumed','FontSize',12);
    
shg;