clear; clc;

% Predator Ecology book, Chapter 8
% Code to make Figure 8.2
% Based on data from Fernando 1977 via Cock 1974
% Data digitzed from Figure 2.B

% functional response parameters fitted to Lambert Random Predator equation
L_a = 0.1338;
L_h = 2.153;
DN_a = 0.1224;
DN_h = 5.533;
t = 24; % duration of experiment

prop_L_offered = [0.2 0.4 0.5 0.6 0.8]; % proportion from x axis
L_offered = 40.*prop_L_offered; % 40 total prey offered
DN_offered = 40 - L_offered;
DN_consumed = [3.32 2.64 2.86 2.62 1.66]; % consumed from y axis
L_consumed = [1.14 1.94 2.95 2.85 6.31];
prop_L_consumed = L_consumed./(DN_consumed + L_consumed);

for i = 1:length(prop_L_offered)
    number_L = L_offered(i); % pull out actual number offered
    number_DN = DN_offered(i);    
    L_guess = 5; % make a guess as to how many were eaten
    DN_guess = 5;
    [z, fval] = fsolve(@(z)MSFR_two_species(z,number_L,number_DN,L_a,L_h,DN_a,DN_h,t),[L_guess DN_guess]);
    Z1(i) = z(1); % log the solution
    Z2(i) = z(2);
end

proportion_L = Z1./(Z1 + Z2); % calculate proportion from totals
proportion_exp = L_a.*L_offered./(DN_a.*DN_offered + L_a.*L_offered);

% linear model regression on observed data
mdl_1 = fitlm(prop_L_offered,prop_L_consumed,'linear'); % fit linear model
x = 0.2:0.1:0.8; % new set of predict x values
[p_S1, ci_S1] = predict(mdl_1,x'); % predict cis of regression line

figure(1); clf(1);
box on; hold on;
    jbfill(x,ci_S1(:,1)',ci_S1(:,2)',[0.9 0.9 0.9],[0.9 0.9 0.9]); hold on;
    z1 = plot(prop_L_offered,prop_L_consumed,'ok','MarkerFaceColor','k');
    z2 = plot([0 1],[0 1],'-','Color',[0 0.45 0.74]);
    z3 = plot(prop_L_offered,proportion_exp,'-','Color','k','LineWidth',2);
    z4 = plot(prop_L_offered,proportion_L,'--','Color',[1 0.55 0],'LineWidth',2);
    legend([z1 z2 z3 z4],'Observed proportion','Strict proportional expectation',...
        'Expectation from {\ita}','MSFR expectation','Location','Best');
    xlabel('Proportion of larvae offered','FontSize',12);
    ylabel('Proportion of larvae in diet','FontSize',12);
shg;
