clear; clc;

% Predator Ecology book, Chapter 8
% Code to make Figure 8.4
% Based on data from Heong et al 1990
% Data digitzed from Figure 2

% MB = myrid bug
% PH = planthopper

% Observed Manly's alpha and ratio of PH:MB
alpha = [0.79 0.77 0.72 0.73 0.66 0.60 0.57 0.62 0.58 0.54 0.48 0.53 0.41 0.36 0.52 0.45 0.40 0.35];
ratio_offered = [0.1667 0.1667 0.1667 0.333 0.333 0.333 0.333 0.5 0.5 0.5 0.5 0.6667 0.6667 0.6667 0.8333 0.8333 0.8333 0.8333];

% functional response parameters fitted to disc equation equation
MB_a = 0.892;
MB_h = 0.019;
PH_a = 0.239;
PH_h = 0.063;
t = 24;

PH_offered = [10 20 30 40 50];
MB_offered = [50 40 30 20 10];
ratios_used = PH_offered./60;

for i = 1:length(ratios_used)
    number_PH = PH_offered(i); % pull out actual number offered
    number_MB = MB_offered(i);    
    PH_guess = 5; % make a guess as to how many were eaten
    MB_guess = 5;
    [z, fval] = fsolve(@(z)MSFR_two_species(z,number_PH,number_MB,PH_a,PH_h,MB_a,MB_h,t),[PH_guess MB_guess]);
    Z1(i) = z(1); % log the solution
    Z2(i) = z(2);
    
    % calculate expected Manly's alpha
    exp_alpha_PH(i) = log((number_PH - Z1(i))/number_PH)/(log((number_PH - Z1(i))/number_PH) + log((number_MB - Z2(i))/number_MB));

end
%%
figure(1);clf(1);
box on; hold on;
    h1 = plot([0 1],[0.5 0.5],'--k');
    h2 = plot(ratios_used,exp_alpha_PH,'-','Color',[0.5 0.5 0.5],'LineWidth',2);
    h3 = plot(ratio_offered,alpha,'ok','MarkerFaceColor','k');
    ylim([0 1]);
    legend([h1 h2 h3],'Standard expectation','MSFR expectation','Observed','Location','Best');
    xlabel('Proporation of planthoppers','FontSize',12);
    ylabel('\alpha_{planthoppers}','FontSize',12);

shg;