clear; clc;

% Predator Ecology book, Chapter 10
% Code to make Figure 10.1
% Functional responses for Norops serranoi lizards foraging on
% Mexican fruit flies (Anastrepha ludens) by sex
% Data from Dor et al 2014

[num,words] = xlsread('BD norops serranoi.xlsx','Males'); % read in data
num_offered_M = num(:,6);
num_eaten_M = num(:,8);

[num,words] = xlsread('BD norops serranoi.xlsx','Females'); % read in data
num_offered_F = num(:,4);
num_eaten_F = num(:,6);

% Set up fittype and options
% Here we will use LambertW version of the Roger's Random Predator Equation
% Duration of the experiment was 6 hours
ft = fittype( 'x - lambertw(a*h*x*exp(-a*(6 - h*x)))/(a*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.Lower = [0 0];

x = 0:1:70; % a sequence of x's to calculate over

[M_result, M_gof] = fit(num_offered_M,num_eaten_M,ft,opts); % do the fit for males
    M_coeffs = coeffvalues(M_result); % output the parameters
    a_M = M_coeffs(1);
    h_M = M_coeffs(2);
    M_rsquare = M_gof.rsquare;
    M_curve_II = x-lambertw(a_M.*h_M.*x.*exp(-a_M.*(6-h_M.*x)))./(a_M.*h_M);

[F_result, F_gof] = fit(num_offered_F,num_eaten_F,ft,opts); % do the fit for females
    F_coeffs = coeffvalues(F_result); % output the parameters
    a_F = F_coeffs(1);
    h_F = F_coeffs(2);
    F_rsquare = F_gof.rsquare;
    F_curve_II = x-lambertw(a_F.*h_F.*x.*exp(-a_F.*(6-h_F.*x)))./(a_F.*h_F);

%% now plot

figure(1);clf(1);
subplot(2,1,1); % males
box on; hold on;
    plot(num_offered_M,num_eaten_M,'ok');
    plot(x,M_curve_II,'-k');
    title('Males');
    ylim([0 50]);
    xlim([0 70]);
    xlabel('Prey offered','FontSize',12);
    ylabel('Prey consumed','FontSize',12);
subplot(2,1,2); % females
box on; hold on;
    plot(num_offered_F,num_eaten_F,'ok');
    plot(x,F_curve_II,'-k');
    xlim([0 70]);
    ylim([0 50]);
    title('Females');
    xlabel('Prey offered','FontSize',12);

shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
