clear; clc;

% Predator Ecology book, Chapter 10
% Code to make Figure 10.2
% Functional responses for Norops serranoi lizards foraging on
% Mexican fruit flies (Anastrepha ludens) by sex
% Data from Dor et al 2014

[num,words] = xlsread('BD norops serranoi.xlsx','Males'); % read in data
num_offered_M = num(:,6);
num_eaten_M = num(:,8);

% Set up fittype and options
% Here we will use LambertW version of the Roger's Random Predator Equation
% Duration of the experiment was 6 hours
ft = fittype( 'x - lambertw(a*h*x*exp(-a*(6 - h*x)))/(a*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.Lower = [0 0];

x = 0:1:70; % a sequence of x's to calculate over

[M_result, M_gof] = fit(num_offered_M,num_eaten_M,ft,opts); % do the fit for males
    M_coeffs = coeffvalues(M_result); % output the parameters
    a_M = M_coeffs(1);
    h_M = M_coeffs(2);
    M_rsquare = M_gof.rsquare;
    M_curve = x-lambertw(a_M.*h_M.*x.*exp(-a_M.*(6-h_M.*x)))./(a_M.*h_M);
    
%%

num_simulations = 300;
y0 = [10 40]; % starting number
t_max = 6; % time frame

figure(2);clf(2);

for j = 1:2
    for i = 1:num_simulations
        t = 0;
        prey_level = y0(j);
            while t(end) < t_max
                if prey_level(end) > 0
                    current_rate = a_M*prey_level(end);
                    time_to_kill = exprnd(1/current_rate);
                    t(end+1) = t(end) + time_to_kill + h_M;
                    prey_level(end+1) = prey_level(end) - 1;
                else
                    break
                end
            end
            figure(2); subplot(2,2,j*2-1);
            hold on; box on;
            plot(t,prey_level,'-','Color',[0.5 0.5 0.5]);
            plot(t(end),prey_level(end),'.','Color',[0.5 0.5 0.5]);
            t_store{i} = t;
            p_store{i} = prey_level;
            within_time = t<6;
            last_predation = find(within_time,1,'last');
            prey_at_end(i) = prey_level(last_predation);
            prey_eaten(i) = y0(j) - prey_level(last_predation);
    end

figure(2); 
subplot(2,2,j*2-1);
    hold on; box on;
    plot(t_max,mean(prey_at_end),'ok','MarkerFaceColor','k');
    plot([t_max t_max],[0 y0(j)],'-k');
    xlim([0 15]);
        xlabel('Time (hours)','Fontsize',12);
        ylabel('Prey uneaten','Fontsize',12);
subplot(2,2,j*2);
    hold on; box on;
    histogram(prey_eaten,6,'FaceColor','k');
    xlim([0 25]);
        xlabel('Number of prey eaten','Fontsize',12);
        ylabel('Frequency','Fontsize',12);

end

subplot(2,2,1);
    title('10 prey offered');
subplot(2,2,2);
    title('10 prey offered');
subplot(2,2,3);
    title('40 prey offered');
subplot(2,2,4);
    title('40 prey offered');

shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
gtext('C','FontSize',12);
gtext('D','FontSize',12);