clear; clc;

% Predator Ecology book, Chapter 10
% Code to make Figure 10.4
% demonstrating the effect of nonlinear average on parameter estimates

%% space clearance rate version
% Define paramaters and make curve
a_M = [0.1:0.1:4.9]; % a sequence of a's to calculate over
mean_a = mean(a_M); % grab mean a
h_M = 0.24; % just set h
x = 25; % just set prey level
curve = x-lambertw(a_M.*h_M.*x.*exp(-a_M.*(6-h_M.*x)))./(a_M.*h_M);
fbar_a = mean(curve); % mean of curve
f_bara = x-lambertw(mean_a.*h_M.*x.*exp(-mean_a.*(6-h_M.*x)))./(mean_a.*h_M); % curve at mean a

% solve for the a given the mean of the curve
fun = @a_from_f; % pick function
F = fsolve(@(a)a_from_f(a,x,h_M,fbar_a,6),1); % use numeric solver
    
% plot a versus number eaten
figure(1); clf(1);
subplot(2,1,1);
    hold on; box on;
    plot(a_M,curve,'-k','LineWidth',2);
    plot([mean_a mean_a],[0 f_bara],'-k');
    plot([0 mean_a],[f_bara f_bara],'-k');
    plot([0 F],[fbar_a fbar_a],'--k');
    plot([F F],[0 fbar_a],'--k');
    plot(F,fbar_a,'ok','MarkerFaceColor','k');
    h1 = text(1,20,'$$\overline{f(a)}$$');
    h2 = text(2,20,'$$f(\overline{a}$$)');
    h3 = text(2.5,10,'$$\overline{a}$$');
    h4 = text(1.5,10,'$$a$$');
        set([h1 h2 h3 h4],'Interpreter','latex','FontSize',14)
    ylim([5 25]);
    xlim([0 5]);
    xlabel('Space clearance rate','FontSize',12);
    ylabel('Prey consumed','FontSize',12);
    
%% now do the handling time version
% Define paramaters and make curve
a_M = 2; % a sequence of a's to calculate over
h_M = [0.1:0.1:0.9]; % just set h
mean_h = mean(h_M); % grab mean a
x = 25; % just set prey level
curve = x-lambertw(a_M.*h_M.*x.*exp(-a_M.*(6-h_M.*x)))./(a_M.*h_M);
fbar_h = mean(curve); % mean of curve
f_barh = x-lambertw(a_M.*mean_h.*x.*exp(-a_M.*(6-mean_h.*x)))./(a_M.*mean_h); % curve at mean a

% solve for the a given the mean of the curve
fun = @h_from_f; % pick function
F = fsolve(@(h)h_from_f(h,x,a_M,fbar_h,6),1); % use numeric solver
    
% plot a versus number eaten
subplot(2,1,2);
    hold on; box on;
    plot(h_M,curve,'-k','LineWidth',2);
    plot([mean_h mean_h],[0 f_barh],'-k');
    plot([0 mean_h],[f_barh f_barh],'-k');
    plot([0 F],[fbar_h fbar_h],'--k');
    plot([F F],[0 fbar_h],'--k');
    plot(F,fbar_h,'ok','MarkerFaceColor','k');
    h1 = text(0.5,20,'$$\overline{f(h)}$$');
    h2 = text(0.5,20,'$$f(\overline{h}$$)');
    h3 = text(0.5,10,'$$\overline{h}$$');
    h4 = text(0.5,10,'$$h$$');
        set([h1 h2 h3 h4],'Interpreter','latex','FontSize',14)
    ylim([5 25]);
    %xlim([0 5]);
    xlabel('Handling time','FontSize',12);
    ylabel('Prey consumed','FontSize',12);
    shg;
    
    gtext('A','FontSize',12);
    gtext('B','FontSize',12);
