clear; clc;

% Predator Ecology book, Chapter 10
% Code to make Figure 10.5
% Differences in the functional responses for male adn female
% Norops serranoi lizards foraging on
% Mexican fruit flies (Anastrepha ludens)
% Data from Dor et al 2014

[num,words] = xlsread('BD norops serranoi.xlsx','Males'); % read in data
num_offered_M = num(:,6);
num_eaten_M = num(:,8);

[num,words] = xlsread('BD norops serranoi.xlsx','Females'); % read in data
num_offered_F = num(:,4);
num_eaten_F = num(:,6);

% combine to one data set with a dummy (0 = male; 1 = female)
num_eaten = [num_eaten_M; num_eaten_F];
num_offered = [num_offered_M; num_offered_F];
dummy_type(1:length(num_offered_M)) = 0;
dummy_type(length(num_offered_M)+1:length(num_eaten)) = 1;

matrix = [num_offered,num_eaten,dummy_type'];

%% Set up fittype and options.
ft = fittype( 'x - lambertw((a+da*y)*(h+dh*y)*x*exp(-(a+da*y)*(6 - (h+dh*y)*x)))/((a+da*y)*(h+dh*y))', 'independent', {'x', 'y'}, 'dependent', 'z' );
opts = fitoptions( 'Method', 'NonlinearLeastSquares' );
opts.Display = 'Off';
opts.Lower = [0 -1 -1 0];
opts.StartPoint = [0.3 0.4 -0.1 0.3];
opts.Upper = [1 1 1 1];

[MF_result, MF_gof] = fit([num_offered,dummy_type'],num_eaten,ft,opts) % do the fit for males
    MF_coeffs = coeffvalues(MF_result); % output the parameters
    da = MF_coeffs(2);
    dh = MF_coeffs(3);
%% now use bootstrapping approach

% now fitting standard type II
ft = fittype( 'x - lambertw(a*h*x*exp(-a*(6 - h*x)))/(a*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( ft );
opts.Display = 'Off';
opts.Lower = [0 0];
opts.StartPoint = [0.5 0.3];
opts.Robust = 'Off';
opts.Upper = [1 Inf];

num_bootstraps = 100; % set number of bootstraps to obtain
num_fits = 0; % start index of number of successful fits
q = 1;

% start with males
while num_fits < num_bootstraps
    num_fits
    index1 = randsample(length(num_offered_M),length(num_offered_M),'true');
    x = num_offered_M(index1);
    y = num_eaten_M(index1);

    try
        [RPE_fitresult, RPE_gof, output] = fit( x, y, ft, opts );
    catch me
    end 
    
    check = exist('me', 'var');
    if check == 1 && contains(me.message,'Inf computed')
    elseif check == 0
        RPE_coeffs = coeffvalues(RPE_fitresult); % output the parameters
        rsquare_M(q) = RPE_gof.rsquare;
        if rsquare_M(q) > 0.1
            a_M(q) = RPE_coeffs(1);
            h_M(q) = RPE_coeffs(2);
            num_fits = num_fits+1;
            q = q+1;
        end
    end
    clear me
end

mean_a_M = prctile(a_M,50)
ci_a_M_97 = prctile(a_M,97.5)
ci_a_M_25 = prctile(a_M,2.5)
mean_M_s = prctile(h_M,50)
ci_h_M_97 = prctile(h_M,97.5)
ci_h_M_25 = prctile(h_M,2.5)
mean_r2_M = mean(rsquare_M)


% move to females
num_fits = 0;
q = 1;

while num_fits < num_bootstraps
    num_fits
    index1 = randsample(length(num_offered_F),length(num_offered_F),'true');
    x = num_offered_F(index1);
    y = num_eaten_F(index1);

    try
        [RPE_fitresult, RPE_gof, output] = fit( x, y, ft, opts );
    catch me
    end 
    
    check = exist('me', 'var');
    if check == 1 && contains(me.message,'Inf computed')
    elseif check == 0
        RPE_coeffs = coeffvalues(RPE_fitresult); % output the parameters
        rsquare_F(q) = RPE_gof.rsquare;
        if rsquare_F(q) > 0.1
            a_F(q) = RPE_coeffs(1);
            h_F(q) = RPE_coeffs(2);
            num_fits = num_fits+1;
            q = q+1;
        end
    end
    clear me
end

mean_a_F = prctile(a_F,50)
ci_a_F_97 = prctile(a_F,97.5)
ci_a_F_25 = prctile(a_F,2.5)
mean_h_F = prctile(h_F,50)
ci_h_F_97 = prctile(h_F,97.5)
ci_h_F_25 = prctile(h_F,2.5)
mean_r2_F = mean(rsquare_F)

%% run pairwise contrasts across all bootstraps

d_a = a_M' - a_F';
    d_a = reshape(d_a,[numel(d_a),1]);
d_h = h_M' - h_F';
    d_h = reshape(d_h,[numel(d_h),1]);

% 95% cis on the difference in a
adiff_95CI_up = prctile(d_a,97.5)
adiff_95CI_down = prctile(d_a,2.5)

% 95% cis on the difference in h
hdiff_95CI_up = prctile(d_h,97.5)
hdiff_95CI_down = prctile(d_h,2.5)

% at what percentile does this cross zero?
perc = prctile(d_h,1:100);
[c index] = min(abs(perc'-0))

%% plot distribution of differences
figure(1);clf(1);
subplot(2,1,1);
hold on; box on;
    hist(d_a,10);
    plot([-da -da],[0 25],'--k','LineWidth',2);
    h1 = findobj(gca,'Type','patch');
    h1.FaceColor = [0.7 0.7 0.7];
    h1.EdgeColor = [0 0 0];
    xlabel('Difference in \ita');
    ylabel('Frequency');
    gtext('A','FontSize',12);
subplot(2,1,2);
hold on; box on;
    hist(d_h);
    plot([-dh -dh],[0 25],'--k','LineWidth',2);
    h = findobj(gca,'Type','patch');
    h.FaceColor = [0.7 0.7 0.7];
    h.EdgeColor = [0 0 0];
    xlabel('Difference in \ith');
    gtext('B','FontSize',12);

shg;