clear; clc;

% Predator Ecology book, Chapter 10
% Code to make Figure 10.7
% Testing for type II or type III in frog functional responses
% Data from Thorpe et al 2020

[num,words] = xlsread('Thorpe data.xlsx','Sheet1'); % read in data

num_offered = num(:,1); % pull all of the prey levels data
num_eaten = num(:,3);
prey_size = words(2:size(words,1),1);

% break data into parts by prey size
num_offered_S = num_offered(ismember(prey_size,'Small'));
num_eaten_S = num_eaten(ismember(prey_size,'Small'));
num_offered_M = num_offered(ismember(prey_size,'Medium'));
num_eaten_M = num_eaten(ismember(prey_size,'Medium'));
num_offered_L = num_offered(ismember(prey_size,'Large'));
num_eaten_L = num_eaten(ismember(prey_size,'Large'));

x = 0:25:500; % a sequence of x's to calculate over
%% fit the type II functional responses

% Set up fittype and options
% Here we will use LambertW version of the Roger's Random Predator Equation
% Duration of the experiment was 14 hours
typeII = fittype( 'x - lambertw(a*h*x*exp(-a*(14 - h*x)))/(a*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( typeII );
opts.Display = 'Off';
opts.StartPoint = [0.1 0.09];
opts.Lower = [0 0];
opts.Upper = [1 1];

[S_result, S_gof] = fit(num_offered_S,num_eaten_S,typeII,opts); % do the fit for small prey
    S_coeffs = coeffvalues(S_result); % output the parameters
    a_S = S_coeffs(1);
    h_S = S_coeffs(2);
    S_rsquare = S_gof.rsquare;
    S_curve_II = x-lambertw(a_S.*h_S.*x.*exp(-a_S.*(14-h_S.*x)))./(a_S.*h_S);
    rss_S = S_gof.sse;
    AIC_S_II = length(num_offered_S)*log(rss_S/length(num_offered_S))+2*2;

[M_result, M_gof] = fit(num_offered_M,num_eaten_M,typeII,opts); % do the fit for medium prey
    M_coeffs = coeffvalues(M_result); % output the parameters
    a_M = M_coeffs(1);
    h_M = M_coeffs(2);
    M_rsquare = M_gof.rsquare;
    M_curve_II = x-lambertw(a_M.*h_M.*x.*exp(-a_M.*(14-h_M.*x)))./(a_M.*h_M);
    rss_M = M_gof.sse;
    AIC_M_II = length(num_offered_M)*log(rss_M/length(num_offered_M))+2*2;

opts.StartPoint = [0.5 0.01];
[L_result, L_gof] = fit(num_offered_L,num_eaten_L,typeII,opts); % do the fit for large prey
    L_coeffs = coeffvalues(L_result); % output the parameters
    a_L = L_coeffs(1);
    h_L = L_coeffs(2);
    L_rsquare = L_gof.rsquare;
    L_curve_II = x-lambertw(a_L.*h_L.*x.*exp(-a_L.*(14-h_L.*x)))./(a_L.*h_L);
    rss_L = L_gof.sse;
    AIC_L_II = length(num_offered_L)*log(rss_L/length(num_offered_L))+2*2;

%% fit the type III functional responses

% Set up fittype and options
% Here we will use LambertW version of the Roger's Random Predator Equation
% Duration of the experiment was 14 hours

typeIII = fittype( 'x - lambertw((b*x^q)*h*x*exp(-(b*x^q)*(14 - h*x)))/((b*x^q)*h)', 'independent', 'x', 'dependent', 'y' );
opts = fitoptions( typeIII );
opts.Display = 'Off';
opts.StartPoint = [0.0008 0.05 0];
opts.Lower = [0 0 -1];

[S_result, S_gof] = fit(num_offered_S,num_eaten_S,typeIII,opts); % do the fit for small prey
    S_coeffs = coeffvalues(S_result); % output the parameters
    b_S = S_coeffs(1);
    h_S = S_coeffs(2);
    q_S = S_coeffs(3);
    S_rsquare = S_gof.rsquare;
    S_curve_III = x - lambertw((b_S.*x.^q_S).*h_S.*x.*exp(-(b_S.*x.^q_S).*(14 - h_S*x)))./((b_S.*x.^q_S).*h_S);
    rss_S = S_gof.sse;
    AIC_S_III = length(num_offered_S)*log(rss_S/length(num_offered_S))+2*3;

opts.StartPoint = [0.008 0.02 0.2];
[M_result, M_gof] = fit(num_offered_M,num_eaten_M,typeIII,opts); % do the fit for medium prey
    M_coeffs = coeffvalues(M_result); % output the parameters
    b_M = M_coeffs(1);
    h_M = M_coeffs(2);
    q_M = M_coeffs(3);
    M_rsquare = M_gof.rsquare;
    M_curve_III = x - lambertw((b_M.*x.^q_M).*h_M.*x.*exp(-(b_M.*x.^q_M).*(14 - h_M*x)))./((b_M.*x.^q_M).*h_M);
    rss_M = M_gof.sse;
    AIC_M_III = length(num_offered_M)*log(rss_M/length(num_offered_M))+2*3;

[L_result, L_gof] = fit(num_offered_L,num_eaten_L,typeIII,opts); % do the fit for large prey
    L_coeffs = coeffvalues(L_result); % output the parameters
    b_L = L_coeffs(1);
    h_L = L_coeffs(2);
    q_L = L_coeffs(3);
    L_rsquare = L_gof.rsquare;
    L_curve_III = x - lambertw((b_L.*x.^q_L).*h_L.*x.*exp(-(b_L.*x.^q_L).*(14 - h_L*x)))./((b_L.*x.^q_L).*h_L);
    rss_L = L_gof.sse;
    AIC_L_III = length(num_offered_L)*log(rss_L/length(num_offered_L))+2*3;
   
%% now use Juliano/polynomial logistic regression to assess type

% for small predators
Y = [num_eaten_S,num_offered_S];
X = num_offered_S;
mdS3 = fitglm([X X.^2 X.^3],Y,'Distribution','binomial','link', 'logit');
mdS2 = fitglm([X X.^2],Y,'Distribution','binomial','link', 'logit');
% significantly negative x^2 term and insignificant x^3 term indicates typeII

% for medium predators
Y = [num_eaten_M,num_offered_M];
X = num_offered_M;
mdM3 = fitglm([X X.^2 X.^3],Y,'Distribution','binomial');
mdM2 = fitglm([X X.^2],Y,'Distribution','binomial');
% significantly negative x and x^3 term with positive x^2 term
% does not conform to Juliano's type II or III criteria

% for large predators
Y = [num_eaten_L,num_offered_L];
X = num_offered_L;
mdL3 = fitglm([X X.^2 X.^3],Y,'Distribution','binomial');
% x^3 is not significant, reduce model terms
mdL2 = fitglm([X X.^2],Y,'Distribution','binomial');
% significantly positive x and negative x^2 terms indicate type III

%% now plot

figure(1);clf(1);
subplot(2,3,1); % males
box on; hold on;
    plot(num_offered_S,num_eaten_S,'ok','MarkerFaceColor','w');
    z2 = plot(x,S_curve_III,'--','Color',[0 0.45 0.74],'LineWidth',2);
    z1 = plot(x,S_curve_II,':','Color',[1 0.55 0],'LineWidth',2);
    legend([z1 z2],'Type II','Type III');
    title('Small prey');
    ylim([0 500]);
    xlim([0 500]);
    ylabel('Prey consumed','FontSize',12);
subplot(2,3,2); % medium prey
box on; hold on;
    plot(num_offered_M,num_eaten_M,'ok','MarkerFaceColor','w');
    plot(x,M_curve_III,'--','Color',[0 0.45 0.74],'LineWidth',2);
    plot(x,M_curve_II,':','Color',[1 0.55 0],'LineWidth',2);
    ylim([0 500]);
    xlim([0 500]);
    title('Medium prey');
subplot(2,3,3); % large prey
box on; hold on;
    plot(num_offered_L,num_eaten_L,'ok','MarkerFaceColor','w');
    plot(x,L_curve_III,'--','Color',[0 0.45 0.74],'LineWidth',2);
    plot(x,L_curve_II,':','Color',[1 0.55 0],'LineWidth',2);
    ylim([0 500]);
    xlim([0 500]);
    title('Large prey');
subplot(2,3,4); % males
box on; hold on;
    plot(num_offered_S,num_eaten_S./num_offered_S,'ok','MarkerFaceColor','w');
    ypred2 = predict(mdS2,[x; x.^2]'); % plot the x^2 fitted model
    ypred3 = predict(mdS3,[x; x.^2; x.^3]');
    plot(x,ypred2,':','Color',[1 0.55 0],'LineWidth',2);
    plot(x,ypred3,'--','Color',[0 0.45 0.74],'LineWidth',2);
    xlim([0 500]);
    xlabel('Prey offered','FontSize',12);
    ylabel('Proportion consumed','FontSize',12);
subplot(2,3,5); % males
box on; hold on;
    plot(num_offered_M,num_eaten_M./num_offered_M,'ok','MarkerFaceColor','w');
    ypred2 = predict(mdM2,[x; x.^2]');
    ypred3 = predict(mdM3,[x; x.^2; x.^3]');
    plot(x,ypred2,':','Color',[1 0.55 0],'LineWidth',2);
    plot(x,ypred3,'--','Color',[0 0.45 0.74],'LineWidth',2);
    xlim([0 500]);
    xlabel('Prey offered','FontSize',12);
subplot(2,3,6); % males
box on; hold on;
    plot(num_offered_L,num_eaten_L./num_offered_L,'ok','MarkerFaceColor','w');
    ypred2 = predict(mdL2,[x; x.^2]');
    ypred3 = predict(mdL3,[x; x.^2; x.^3]');
    plot(x,ypred2,':','Color',[1 0.55 0],'LineWidth',2);
    plot(x,ypred3,'--','Color',[0 0.45 0.74],'LineWidth',2);
    xlim([0 500]);
    xlabel('Prey offered','FontSize',12);

shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
gtext('C','FontSize',12);
gtext('D','FontSize',12);
gtext('E','FontSize',12);
gtext('F','FontSize',12);