clear; clc;

% Predator Ecology book, Chapter 11
% Code to make Figure 11.1
% Comparison of functional response parameters from foraging trials and 
% ODE fitting approaches

%% one panel box plot

% estimates of a and h from trials
a1 = [1.02E-06 1.02E-06 5.74E-07]; % [m^3 per pred per day] (Hewett 1980, via FoRAGE 2018)
a2 = [14.02 0.44 1.43 8.13 3.21 0.79 1.81 1.23 48.44 13.4 4.14 22.02 4.87 1.95 1.08 0.04]; % [mL per pred per day] DeLong_and_Vasseur_2013
a3 = [0.1092]; % [m^3 per pred per day] (Li and Montagnes 2015)
a_trials = [a1 a2/1e6 a2/1e6]; % combine sources and adjust units

h1 = [3.72E-02 4.97E-02 5.82E-02]; % [days] (Hewett 1980, via FoRAGE 2018)
h2 = [0.01 0.004 0.008 0.002 0.005 0.019 0.003 0.006 0.006 ];  % [days] (non-zero estimates from DeLong_and_Vasseur_2013)
h3 = [0.0351]; % [days] (Li and Montagnes 2015)
h_trials = [h1 h2 h3]; % combine sources

% estimates of a and h from ODE fitting
a1_ODE = [9.06]; % [cm^3 per pred per day] (DeLong et al 2014)
a2_ODE = [0.045]; % [cm^3 per pred per day] (Jost and Ellner 2000)
a3_ODE = [0.28 1.501 1.818 31.651 96.229 1.273]; % [cm^3 per pred per day] (DeLong and Lyon 2020)
a_ODE = [a1_ODE/1e6 a2_ODE/1e6 a3_ODE/1e6];

h1_ODE = [3.8e-2]; % [days] (DeLong et al 2014)
h2_ODE = [2.1e-2]; % [days] (Jost and Ellner 2000)
h3_ODE = [0.08 0.073 0.064 0.040 0.045 0.011]; % [days] (DeLong and Lyon 2020)
h_ODE = [h1_ODE h2_ODE h3_ODE];

figure(1);clf(1);
subplot(1,2,1);
    hold on; box on;
    z2 = histfit(log(a_ODE));
        z2(2).LineStyle = '--';
        z2(2).Color = [0 0.45 0.74];
        delete(z2(1));
    z1 = histfit(log(a_trials));
        z1(2).Color = [1 0.55 0];
        delete(z1(1));
    xlabel('ln(Space clearance rate)','FontSize',12);
    ylabel('Frequency','FontSize',12);
    legend('ODE fitting','Trials');
subplot(1,2,2);
    hold on; box on;
    z2 = histfit(log(h_ODE));
        z2(2).LineStyle = '--';
        z2(2).Color = [0 0.45 0.74];
        delete(z2(1));
    z1 = histfit(log(h_trials));
        z1(2).Color = [1 0.55 0];
        delete(z1(1));
    xlabel('ln(Handling time)','FontSize',12);
shg;

gtext('A','FontSize',12);
gtext('B','FontSize',12);
